@@ -1,6 +1,6 @@
 stab.version<-function(){
 cat("\n")
-cat("------------------ stab for R v0.1.7 ------------------\n")
+cat("------------------ stab for R v0.1.8 ------------------\n")
 cat("\n developed by Hsin-ya Lee and Yung-jin Lee, 2007-2013.\n")
-cat("\n This report was generated on",date(),"\n")
+cat(" This report was generated on",date(),"\n")
 cat("\n\n")}
\ No newline at end of file
